@@ -36,9 +36,11 @@ class UrlBuilder(metaclass = _Singleton):
         self.base_url = main_url
         self.portal = portal
         
+    def _base_orion_url(self):
+        return self.base_url + self.ORION_HEADER
 
     def _api_header_url(self):
-        return self.base_url + self.ORION_HEADER + "/admin/tree"
+        return self._base_orion_url() + "/admin/tree"
 
     def token_url(self):
         """
@@ -162,7 +164,7 @@ class UrlBuilder(metaclass = _Singleton):
         """
         return self.right_management_profiles_url(profile_id) + "/BUSINESS/Cadastre"
 
-    # ----- Stats resource urls -----
+    # ----- Business resource urls -----
     def businesses_children_url(self, business_access=""):
         """
         :return: url to get all services defined in orion.
@@ -190,6 +192,7 @@ class UrlBuilder(metaclass = _Singleton):
         """
         return self._api_header_url() + "/object/BUSINESS"
 
+    # ----- Stats resource urls -----
     def stats_resource_url(self, storage_id=""):
         resource_url = self.main_businesses_url() + "/Stats"
         if storage_id:
@@ -199,6 +202,24 @@ class UrlBuilder(metaclass = _Singleton):
     def stats_configuration_url(self, storage_id):
         return self.stats_resource_url(storage_id) + self.CONFIGURE
 
+    def stats_status_url(self):
+        return self._base_orion_url() + "/stats/status"
+
+    def stats_push_url(self):
+        return self._base_orion_url() + "/stats/push"
+
+    def stats_heartBeat_url(self):
+        return self._base_orion_url() + "/stats/heartBeat"
+
+    def stats_newSession_url(self):
+        return self._base_orion_url() + "/stats/newSession"
+
+    def stats_synthesis_url(self):
+        return self._base_orion_url() + "/stats/synthesis"
+
+    def stats_clean_url(self):
+        return self._base_orion_url() + "/stats/clean"
+
     # ----- Service urls -----
     def services_children_url(self, service_access=""):
         """
@@ -216,7 +237,7 @@ class UrlBuilder(metaclass = _Singleton):
         :return: url to get the list of services managed by Orion
         :Example: https://front.arcopole.fr/Orion/orion/federatedLink/managedServiceList
         """
-        return self.base_url + self.ORION_HEADER + "/federatedLink/managedServiceList"
+        return self._base_orion_url() + "/federatedLink/managedServiceList"
 
     def main_services_url(self):
         """
@@ -366,8 +387,8 @@ class UrlBuilder(metaclass = _Singleton):
         :Example: https://front.arcopole.fr/Orion/orion/geonote or https://front.arcopole.fr/Orion/orion/project
         """
         if f_type == "Feature Collection":
-            return self.base_url + self.ORION_HEADER + "/geonote"
-        return self.base_url + self.ORION_HEADER + "/project"
+            return self._base_orion_url() + "/geonote"
+        return self._base_orion_url() + "/project"
 
     def search_feature_url(self, f_type):
         """
